==> jupyter_server_ydoc-0.1.13.tar.gz: jupyter_server_ydoc-0.1.13/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.13

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.12...43ec5733539b1679f82b71d76db8946f59aad534))

### Enhancements made

- Don't unobserve and observe again [#39](https://github.com/jupyter-server/jupyter_server_ydoc/pull/39) ([@davidbrochart](https://github.com/davidbrochart))

### Maintenance and upkeep improvements

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-09-26&to=2022-10-26&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Acodecov-commenter+updated%3A2022-09-26..2022-10-26&type=Issues) | [@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-09-26..2022-10-26&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-09-26..2022-10-26&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Awelcome+updated%3A2022-09-26..2022-10-26&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.12

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.11...91e48a84163d5a812a16ed61287d0ce345981ee7))

### Enhancements made

### Maintenance and upkeep improvements

- Switch to hatch version [#33](https://github.com/jupyter-server/jupyter_server_ydoc/pull/33) ([@davidbrochart](https://github.com/davidbrochart))
- Update to YDoc 0.2 [#32](https://github.com/jupyter-server/jupyter_server_ydoc/pull/32) ([@hbcarlos](https://github.com/hbcarlos))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-08-08&to=2022-09-26&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Acodecov-commenter+updated%3A2022-08-08..2022-09-26&type=Issues) | [@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-08-08..2022-09-26&type=Issues) | [@hbcarlos](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Ahbcarlos+updated%3A2022-08-08..2022-09-26&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-08-08..2022-09-26&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Awelcome+updated%3A2022-08-08..2022-09-26&type=Issues)

## 0.1.11

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.10...d7e728b0c773977c6a307d7a8878b40c6be3a13d))

### Enhancements made

- Implement filtering in on_message [#25](https://github.com/jupyter-server/jupyter_server_ydoc/pull/25) ([@davidbrochart](https://github.com/davidbrochart))

### Maintenance and upkeep improvements

- [pre-commit.ci] pre-commit autoupdate [#24](https://github.com/jupyter-server/jupyter_server_ydoc/pull/24) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-30&to=2022-08-08&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Acodecov-commenter+updated%3A2022-07-30..2022-08-08&type=Issues) | [@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-30..2022-08-08&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-07-30..2022-08-08&type=Issues)

## 0.1.10

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.9...821fd7124480b5a1dbe723f1188da6083ad1f332))

### Enhancements made

- Add TransientRoom [#22](https://github.com/jupyter-server/jupyter_server_ydoc/pull/22) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-29&to=2022-07-30&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-29..2022-07-30&type=Issues)

## 0.1.9

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.8...1eb8c61f9962b9d0b9b67538946e2041d816e317))

### Bugs fixed

- Support Jupyter server base URL [#20](https://github.com/jupyter-server/jupyter_server_ydoc/pull/20) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-27&to=2022-07-29&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-27..2022-07-29&type=Issues)

## 0.1.8

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.7...8c8e3f086a80c07b58257adfe19887385fd2ff4c))

### Enhancements made

- Bump dependencies [#18](https://github.com/jupyter-server/jupyter_server_ydoc/pull/18) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-26&to=2022-07-27&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-26..2022-07-27&type=Issues)

## 0.1.7

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.6...1a43251c35a4a59fa2b8439d72fc8a5e2db669f9))

### Enhancements made

- Bump jupyter_ydoc=0.1.14 [#16](https://github.com/jupyter-server/jupyter_server_ydoc/pull/16) ([@davidbrochart](https://github.com/davidbrochart))

### Maintenance and upkeep improvements

- [pre-commit.ci] pre-commit autoupdate [#15](https://github.com/jupyter-server/jupyter_server_ydoc/pull/15) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-25&to=2022-07-26&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-25..2022-07-26&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-07-25..2022-07-26&type=Issues)

## 0.1.6

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.5...a90fec40d3b79e0fea564308e93d0868674250e5))

### Bugs fixed

- Fix typing for python <=3.8 [#13](https://github.com/jupyter-server/jupyter_server_ydoc/pull/13) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-25&to=2022-07-25&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-25..2022-07-25&type=Issues)

## 0.1.5

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.4...382cfd1d2a2676880cfcb210e3a15dc7e342c070))

### Enhancements made

- Save Y updates using YStore [#2](https://github.com/jupyter-server/jupyter_server_ydoc/pull/2) ([@davidbrochart](https://github.com/davidbrochart))

### Maintenance and upkeep improvements

- [pre-commit.ci] pre-commit autoupdate [#11](https://github.com/jupyter-server/jupyter_server_ydoc/pull/11) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#10](https://github.com/jupyter-server/jupyter_server_ydoc/pull/10) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-11&to=2022-07-25&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-11..2022-07-25&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-07-11..2022-07-25&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Awelcome+updated%3A2022-07-11..2022-07-25&type=Issues)

## 0.1.4

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.3...3b6db1b0cb6e4a060af9f350b1d62396992931f9))

### Merged PRs

- Fix changelog [#8](https://github.com/jupyter-server/jupyter_server_ydoc/pull/8) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-11&to=2022-07-11&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-11..2022-07-11&type=Issues)

## 0.1.3

## 0.1.2

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.1...36bf3c1908d850fc11fb784a6adead4be86f3e4a))

### Bugs fixed

- Fix jupyter_server import [#5](https://github.com/jupyter-server/jupyter_server_ydoc/pull/5) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-11&to=2022-07-11&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-11..2022-07-11&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/d175b8a607985886ef0fd51af994ae186b527c12...e91f593a4213e314508418e951dc3aa3bb66cdcf))

### Bugs fixed

- Remove docs link for now [#3](https://github.com/jupyter-server/jupyter_server_ydoc/pull/3) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-10&to=2022-07-10&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-10..2022-07-10&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Awelcome+updated%3A2022-07-10..2022-07-10&type=Issues)

## 0.1.0

==> jupyter_server_ydoc-0.1.14.tar.gz: jupyter_server_ydoc-0.1.14/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.14

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.13...547667399adeefcf2729a2c76b4526e752efdbf6))

### Enhancements made

- Use Jupyter file ID service if installed [#41](https://github.com/jupyter-server/jupyter_server_ydoc/pull/41) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-10-26&to=2022-10-28&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-10-26..2022-10-28&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.13

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.12...43ec5733539b1679f82b71d76db8946f59aad534))

### Enhancements made

- Don't unobserve and observe again [#39](https://github.com/jupyter-server/jupyter_server_ydoc/pull/39) ([@davidbrochart](https://github.com/davidbrochart))

### Maintenance and upkeep improvements

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-09-26&to=2022-10-26&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Acodecov-commenter+updated%3A2022-09-26..2022-10-26&type=Issues) | [@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-09-26..2022-10-26&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-09-26..2022-10-26&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Awelcome+updated%3A2022-09-26..2022-10-26&type=Issues)

## 0.1.12

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.11...91e48a84163d5a812a16ed61287d0ce345981ee7))

### Enhancements made

### Maintenance and upkeep improvements

- Switch to hatch version [#33](https://github.com/jupyter-server/jupyter_server_ydoc/pull/33) ([@davidbrochart](https://github.com/davidbrochart))
- Update to YDoc 0.2 [#32](https://github.com/jupyter-server/jupyter_server_ydoc/pull/32) ([@hbcarlos](https://github.com/hbcarlos))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-08-08&to=2022-09-26&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Acodecov-commenter+updated%3A2022-08-08..2022-09-26&type=Issues) | [@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-08-08..2022-09-26&type=Issues) | [@hbcarlos](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Ahbcarlos+updated%3A2022-08-08..2022-09-26&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-08-08..2022-09-26&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Awelcome+updated%3A2022-08-08..2022-09-26&type=Issues)

## 0.1.11

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.10...d7e728b0c773977c6a307d7a8878b40c6be3a13d))

### Enhancements made

- Implement filtering in on_message [#25](https://github.com/jupyter-server/jupyter_server_ydoc/pull/25) ([@davidbrochart](https://github.com/davidbrochart))

### Maintenance and upkeep improvements

- [pre-commit.ci] pre-commit autoupdate [#24](https://github.com/jupyter-server/jupyter_server_ydoc/pull/24) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-30&to=2022-08-08&type=c))

[@codecov-commenter](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Acodecov-commenter+updated%3A2022-07-30..2022-08-08&type=Issues) | [@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-30..2022-08-08&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-07-30..2022-08-08&type=Issues)

## 0.1.10

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.9...821fd7124480b5a1dbe723f1188da6083ad1f332))

### Enhancements made

- Add TransientRoom [#22](https://github.com/jupyter-server/jupyter_server_ydoc/pull/22) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-29&to=2022-07-30&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-29..2022-07-30&type=Issues)

## 0.1.9

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.8...1eb8c61f9962b9d0b9b67538946e2041d816e317))

### Bugs fixed

- Support Jupyter server base URL [#20](https://github.com/jupyter-server/jupyter_server_ydoc/pull/20) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-27&to=2022-07-29&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-27..2022-07-29&type=Issues)

## 0.1.8

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.7...8c8e3f086a80c07b58257adfe19887385fd2ff4c))

### Enhancements made

- Bump dependencies [#18](https://github.com/jupyter-server/jupyter_server_ydoc/pull/18) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-26&to=2022-07-27&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-26..2022-07-27&type=Issues)

## 0.1.7

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.6...1a43251c35a4a59fa2b8439d72fc8a5e2db669f9))

### Enhancements made

- Bump jupyter_ydoc=0.1.14 [#16](https://github.com/jupyter-server/jupyter_server_ydoc/pull/16) ([@davidbrochart](https://github.com/davidbrochart))

### Maintenance and upkeep improvements

- [pre-commit.ci] pre-commit autoupdate [#15](https://github.com/jupyter-server/jupyter_server_ydoc/pull/15) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-25&to=2022-07-26&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-25..2022-07-26&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-07-25..2022-07-26&type=Issues)

## 0.1.6

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.5...a90fec40d3b79e0fea564308e93d0868674250e5))

### Bugs fixed

- Fix typing for python <=3.8 [#13](https://github.com/jupyter-server/jupyter_server_ydoc/pull/13) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-25&to=2022-07-25&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-25..2022-07-25&type=Issues)

## 0.1.5

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.4...382cfd1d2a2676880cfcb210e3a15dc7e342c070))

### Enhancements made

- Save Y updates using YStore [#2](https://github.com/jupyter-server/jupyter_server_ydoc/pull/2) ([@davidbrochart](https://github.com/davidbrochart))

### Maintenance and upkeep improvements

- [pre-commit.ci] pre-commit autoupdate [#11](https://github.com/jupyter-server/jupyter_server_ydoc/pull/11) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#10](https://github.com/jupyter-server/jupyter_server_ydoc/pull/10) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-11&to=2022-07-25&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-11..2022-07-25&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Apre-commit-ci+updated%3A2022-07-11..2022-07-25&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Awelcome+updated%3A2022-07-11..2022-07-25&type=Issues)

## 0.1.4

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.3...3b6db1b0cb6e4a060af9f350b1d62396992931f9))

### Merged PRs

- Fix changelog [#8](https://github.com/jupyter-server/jupyter_server_ydoc/pull/8) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-11&to=2022-07-11&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-11..2022-07-11&type=Issues)

## 0.1.3

## 0.1.2

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/v0.1.1...36bf3c1908d850fc11fb784a6adead4be86f3e4a))

### Bugs fixed

- Fix jupyter_server import [#5](https://github.com/jupyter-server/jupyter_server_ydoc/pull/5) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-11&to=2022-07-11&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-11..2022-07-11&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/jupyter-server/jupyter_server_ydoc/compare/d175b8a607985886ef0fd51af994ae186b527c12...e91f593a4213e314508418e951dc3aa3bb66cdcf))

### Bugs fixed

- Remove docs link for now [#3](https://github.com/jupyter-server/jupyter_server_ydoc/pull/3) ([@davidbrochart](https://github.com/davidbrochart))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/jupyter_server_ydoc/graphs/contributors?from=2022-07-10&to=2022-07-10&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Adavidbrochart+updated%3A2022-07-10..2022-07-10&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fjupyter_server_ydoc+involves%3Awelcome+updated%3A2022-07-10..2022-07-10&type=Issues)

## 0.1.0
